youtubedlapi-server-infusiblecoder
=====================

A REST API server for getting the info for videos from different sites, powered by `yt-dlp <http://rg3.github.io/yt-dlp/>`_.
The installation instructions and the documentation are available at `Read the Docs <https://youtubedlapi-server-infusiblecoder.readthedocs.io/>`_.

About
-----

``youtubedlapi-server-infusiblecoder`` is released to the public domain, read the `license <LICENSE>`_ for more info.
